@@ -23,7 +23,7 @@ class TorchFormat(Format[T], Generic[T]):
 
     """
 
-    VERSION = 2
+    VERSION = "002"
 
     def write(self, artifact: T, dir: PathOrStr):
         filename = Path(dir) / "data.pt"
@@ -39,6 +39,3 @@ class TorchFormat(Format[T], Generic[T]):
                     f"File {filename} is too recent for this version of {self.__class__}."
                 )
             return artifact
-
-    def checksum(self, dir: PathOrStr) -> str:
-        return self._checksum_artifact(Path(dir) / "data.pt")
